# -*- coding: utf-8 -*-
"""Management command to create a new AccessToken."""
import logging

from django.core.management.base import BaseCommand
from optparse import make_option

from perimeter.models import AccessToken

logger = logging.getLogger(__name__)


class Command(BaseCommand):

    help = "Create a perimeter access token."

    option_list = BaseCommand.option_list + (
        make_option(
            '-t', '--token',
            action='store',
            dest='token',
            help='User supplied token (max 10 chars)'
        ),
    )

    def handle(self, *args, **options):

        if options.get('token'):
            token = AccessToken.objects.create_access_token(token=options.get('token'))
        else:
            token = AccessToken.objects.create_access_token()

        logger.info('Created new access token: "%s"', token.token)


# -*- coding: utf-8 -*-
# perimeter view tests
from django.core.urlresolvers import reverse
from django.test import TestCase, RequestFactory, override_settings

from perimeter.models import AccessToken, AccessTokenUse
from perimeter.views import resolve_return_url, gateway


class PerimeterViewTests(TestCase):

    def setUp(self):
        self.factory = RequestFactory()
        self.url = reverse('perimeter:gateway')

    def test_display_gateway_GET_200(self):
        """GET on the perimeter:gateway should work."""
        request = self.factory.get(self.url)
        response = gateway(request)
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(response, 'gateway.html')

    def test_display_gateway_POST_302(self):
        """POST on the perimeter:gateway should work."""
        token = AccessToken.objects.create_access_token()
        payload = {
            'token': token.token,
            'email': 'hugo@example.com',
            'name': 'Hugo Rodger-Brown',
        }
        request = self.factory.post(self.url, payload)
        request.session = {}
        response = gateway(request)
        self.assertEqual(response.status_code, 302)
        usage = AccessTokenUse.objects.get()
        self.assertEqual(usage.user_email, payload['email'])
        self.assertEqual(usage.user_name, payload['name'])
        self.assertEqual(usage.token, token)

    def test_resolve_return_url(self):
        default_url = reverse('perimeter:gateway')
        for url in (None, 'x/y/z/', default_url):
            self.assertEqual(resolve_return_url(url), default_url)



# -*- coding: utf-8 -*-
# perimeter settings file
from django.conf import settings
# if False, the middleware will be disabled
PERIMETER_ENABLED = getattr(settings, 'PERIMETER_ENABLED', True)
# request.session key used to store user's token
PERIMETER_SESSION_KEY = getattr(settings, 'PERIMETER_SESSION_KEY', "perimeter")
# default expiry, in days, of a token
PERIMETER_DEFAULT_EXPIRY = getattr(settings, 'PERIMETER_DEFAULT_EXPIRY', 7)
